<?php

require_once 'lib/3rdparty/Michelf/MarkdownExtra.inc.php';
use Michelf\MarkdownExtra;
        
class GILSUtils {

    /** Introduced in websites/Gitlab-Issue-Listing-Script#39
     * 
     */
    public static function buildLabelCSS($label){

        $t = ".labelid-" . htmlspecialchars($label['id']) . "{" .
        "background-color: " . $label['bgcolour'] . ";" .
        "color: " . $label['textcolour'] . ";" .
        "}";
        return $t;
    }

    public static function parseLinkHeader($link){
        $parts = explode(",", $link);
        $x = 0;
        $vals = array();
        foreach ($parts as $part){
            $p = explode(";", $part);
            $link = str_replace(array("<",">"),"",$p[0]);
            $rel = explode('"',$p[1])[1];
            $vals[$rel] = array(
                "link" => GILSUtils::forceHTTPS($link),
                "rel" => $rel
            );
            $x++;
        }
        return $vals;
    }

    public static function forceHTTPS($url){
        global $config;
        return ($config->force_https) ? str_replace("http://", "https://", $url) : $url;
    }
    
    
    public static function markdownToHTML($md){
        return MarkdownExtra::defaultTransform($md);
    }
    
    
    public static function qs2sef($qs, $ext=".html"){
            $pairs = explode("&", $qs);
            
            $set = array();
            $url = array();
            foreach ($pairs as $pair){
                $ps = explode("=", $pair);
                $set[$ps[0]] = $ps[1];
            }
    
            if (isset($set['proj'])){
                $url[] = "project";
                $url[] = str_replace(" ","-",$set['proj']);
            }elseif(isset($set['issue'])){
                // issue={$issue['gitlab_reference']}
                $url[] = "issue";
                $issref = str_replace("#", "/", $set['issue']);
                
                if ($issref[0] == "/"){
                    // There's no project reference, we need to try and figure that out
                    
                    // first, remove the leading slash
                    $issref = ltrim($issref, "/");
                    
                    // What are we currently viewing?
                    $here = GILSUtils::sef2qs($_SERVER['REQUEST_URI']);
                    
                    // Does the have a project name in it?
                    if (array_key_exists("subsection", $here) && !empty($here["subsection"])){
                        // It does, use that
                        $url[] = $here["subsection"];
                    }else{
                        // Best efforts then, return a relative link
                        return $issref . $ext;
                    }
                }elseif(substr_count($issref, "/") == 1){
                    // It's a partial reference (websites/Gitlab-Issue-Listing-Script#41)

                    // What are we currently viewing?
                    $here = GILSUtils::sef2qs($_SERVER['REQUEST_URI']);

                    // Does the have a project name in it?
                    if (array_key_exists("subsection", $here) && !empty($here["subsection"])){
                        // It does, use that
                        $parts = explode("/", $here["subsection"]);
                        $url[] = $parts[0];
                    }

                }
                
                $url[] = $issref;
            }elseif(isset($set['milestone'])){
                $url[] = "milestone";
                $url[] = $set['projpath'];
                $url[] = $set['milestone'];
                
            }elseif(isset($set['release'])){
                $url[] = "release";
                $url[] = $set['projpath'];
                $url[] = $set['release'];
            }elseif(isset($set['snapshot'])){    
                $url[] = "snapshot";
                $url[] = $set['snapshot'];
                $ext = "";
                
            }elseif(isset($set['wiki'])){
                $url[] = "wiki";
                $url[] = $set['wiki'];
                if (isset($set['page'])){
                    $url[] = "page";
                    $url[] = $set['page']; # this is the slug
                }else{
                    $url[] = "list";
                }
            }elseif(isset($set['commit'])){
                    //commit={$commit}&proj={$pth}
                    $url[] = "commits";
                    
                    // websites/Gitlab-Issue-Listing-Script#41
                    //
                    // Handle relative commits
                    
                    if (empty($set['commitproj'])){
                        // Should never happen
                        $here = GILSUtils::sef2qs($_SERVER['REQUEST_URI']);
                        // Does the have a project name in it?
                        if (array_key_exists("subsection", $here) && !empty($here["subsection"])){
                            // It does, use that
                            $url[] = $here["subsection"];                        
                        }
                    }elseif(!str_contains($set['commitproj'], "/")){
                        // It's a partial reference
                        $here = GILSUtils::sef2qs($_SERVER['REQUEST_URI']);
                        if (array_key_exists("subsection", $here) && !empty($here["subsection"])){
                            // It does, use that
                            $parts = explode("/", $here['subsection']);
                            $url[] = $parts[0] . "/" . $set['commitproj'];
                        }                        
                    }else{
                        $url[] = $set['commitproj'];
                    }
                    
                    
                    if(isset($set['commit'])){
                        $url[] = $set['commit'];
                    }else{
                        $url[] = "list";
                    }
            }elseif(isset($set['container'])){
                    $url[] = "containers";
                    $url[] = $set['contproj'];
                    $url[] = $set['container'];
            }
    
    
            return "/".implode("/", $url).$ext;
    }
    
    public static function sef2qs($sef){
        $path_split = explode("/", str_replace(".html", "",$sef));
        
        if (count($path_split) == 1 || $path_split[1] == "" || $path_split[1] == "index"){
            return array(
                    "section" => "projects"
            );
        }
        
        switch($path_split[1]){
            case "avatars":
                return array(
                    "section" => "avatars",
                    "path" => implode("/", array_slice($path_split, -2))
                );
                break;
            
            case "commits":
                return array(
                    "section" => "commits",
                    "subsection" => implode("/",array($path_split[2], $path_split[3])),
                    "commit" => end($path_split)
                    );
            
            case "containers":
                return array(
                    "section" => "containers",
                    "subsection" => implode("/",array($path_split[2], $path_split[3])),
                    "container" => end($path_split)
                    );            
            
            case "milestone":
                return array(
                    "section" => "milestone",
                    "subsection" => implode("/", array($path_split[2], $path_split[3])),
                    "milestone" => end($path_split)
                    );
                
            case "project":
                return array(
                    "section" => "project",
                    "subsection" => implode("/",array_slice($path_split, -2)),
                    "mode" => "list",
                    "sef" => $sef        
                );
                
            case "release":
                return array(
                    "section" => "release",
                    "subsection" => implode("/", array($path_split[2], $path_split[3])),
                    "release" => end($path_split)
                    );
                
            case "snapshot":
                
                array_shift($path_split);
                array_shift($path_split);
                
                return array(
                    "section" => "snapshot",
                    "snapshot" => implode("/", $path_split)
                    );
                
            case "system_avatars":
                // Strip any trailing filename extension
                $end = array_pop($path_split);
                $parts = explode(".", $end);
                array_pop($parts);
                $path_split[] = implode(".", $parts);
                
                
                return array(
                    "section" => "system_avatars",
                    "path" => implode("/", array_slice($path_split, 2))
                );
                break;
                
            case "issue":
                if ($path_split[4] == "uploads"){
                    // It's an image request
                    return array(
                        "section" => "issue",
                        "subsection" => implode("/",array($path_split[2], $path_split[3])),
                        "issid" => false,
                        "img_path" => implode("/",array_slice($path_split, -3)),
                        "sef" => $sef                        
                    );
                }
            
                return array(
                    "section" => "issue",
                    "subsection" => implode("/",array_slice(array_slice($path_split, -3),0, 2)),
                    "issid" => end($path_split),
                    "sef" => $sef                        
                );
                
            case "wiki":
                if (count($path_split) > 5 && $path_split[5] == "uploads"){
                    // It's an image request
                    return array(
                        "section" => "wiki",
                        "subsection" => implode("/",array($path_split[2], $path_split[3])),
                        "page" => false,
                        "img_path" => implode("/",array_slice($path_split, -3)),
                        "sef" => $sef,
                        "action" => "image"
                    );
                }
                
                $act = $path_split[4];
                $page = "";
                if ($act == "page"){
                    $page = $path_split[5];
                }
                return array(
                    "section" => "wiki",
                    "subsection" => implode("/", array($path_split[2], $path_split[3])),
                    "action" => $act,
                    "page" => $page
                );
                
                
            case "status":
                return array(
                  "section" => "status"  
                );
            default:
                return array(
                    "section" => "404"
                );            
        }
    }
    
    public static function translateUser($user){
        return $user;
    }
      
      
    public static function replaceCommitRefsEtc($md, $project_path){
        /** Detect commit hashes in a block of markdown and replace it with a link
        
         Implemented for websites/Gitlab-Issue-Listing-Script#8
        
        */
    
    
        $proj_path_chars="0-9a-zA-Z_\-\/\.";
        // Commits
        // ((([^\ ]+@)?)([a-f,0-9]{40}))
        $matches = array();
        preg_match_all("((([$proj_path_chars]+@)?)([a-f,0-9]{40}))", $md, $matches);
        
        if (count($matches) > 0 && count($matches[0]) > 0){
            // iter over, calculate and perform the replacement
            foreach($matches[0] as $ref){
                $splt = explode("@", $ref);
                $pth = (count($splt) == 1) ? $project_path : $splt[0];
                $commit = (count($splt) == 1) ? $splt[0] : $splt[1];
                $sc = substr($commit, 0, 7);
               
                $newlink = GILSUtils::qs2sef("commit={$commit}&commitproj={$pth}");
               
                // Turn it into a link
                $newmd = "[$sc]($newlink)";
                $md = str_replace($ref, $newmd, $md);
            }
        
        }
        
        
        // Project references
        // (([a-zA-Z-\/]+)?)(#[0-9]+)
        $matches = array();
        preg_match_all("((([$proj_path_chars]+)?)(#[0-9]+))", $md, $matches);
        
        if (count($matches) > 0 && count($matches[0]) > 0){
            // iter over, calculate and perform the replacement
            foreach($matches[0] as $ref){
                //echo $ref;
                $splt = explode("#", $ref);
                $pth = (count($splt) == 1) ? $project_path : $splt[0];
                $issno = (count($splt) == 1) ? $splt[0] : $splt[1];              
                $nref="{$pth}#$issno";
                $link = GILSUtils::qs2sef("issue={$ref}");
               
                // Turn it into a link
                $newmd = "[$nref]($link)";
                $md = str_replace($ref, $newmd, $md);
            }
        
        }
        return $md;
    }
      
      
      
    public static function getAvatarUrl($url){
        if ($url == ""){
            return False;
        }
    
        $url_parts = explode("/", $url);
        
        if ($url_parts[3] != "uploads"){
            // websites/Gitlab-Issue-Listing-Script#31
            // 
            // The avatar is coming from repo metadata instead
            $url_a = array("system_avatars");
            
            # Strip the last two elements from the url
            array_pop($url_parts);
            array_pop($url_parts);
            
            # We also don't want scheme, domain etc
            array_shift($url_parts);
            array_shift($url_parts);
            array_shift($url_parts);
            
            foreach($url_parts as $a){
                $url_a[] = $a;
            }
            
            # Try and figure out the file extension
            $gitlabapi = new GILSGitlab();
            $r = $gitlabapi->getImageMetadata($url);
            
            $ext = "";
            if (array_key_exists("content-type",$r['headers'])){
                switch($r['headers']['content-type'][0]){
                    case "image/png":
                        $ext = ".png";
                        break;

                    case "image/jpg":
                        $ext = ".jpg";
                        break;

                        
                    default:
                        $ext = "";
                }
            }
            return "/". implode("/", $url_a) . $ext;
        }
        
        // Otherwise
        $url_a=array('avatars');
        foreach(array_slice($url_parts, -2) as $a){
            $url_a[] = $a;
        }
        return "/". implode("/", $url_a);
    }
    
    /** Return an array of config values
     * 
     * This method exists so that we don't have to give
     * templates access to global config - the aim being
     * to reduce the risk of someone finding a way to dump
     * out config and get the secrets stored there.
     * 
     */
    public static function getTemplateConfig(){
        global $config;
        
        return array(
            "display_gitlab_links" => $config->display_gitlab_links
            );
    }
}
