<?php
/** Gitlab Issue List Script
*
* Simple script to generate an simple HTML listing of Gitlab Issues from a Private Gitlab Instance
*
* @copyright (C) 2021 B Tasker (http://www.bentasker.co.uk). All rights reserved
* @license GNU GPL V3 - See LICENSE
*
* @version 1.2
*
*/

defined('listpage') or die;
?>
<html>
<head>
<meta name="viewport" content="width=device-width, initial-scale=1">
<title>Commit <?php echo htmlspecialchars($commit['commit']->short_id); ?></title>

<?php require 'head-includes.php'; ?>
</head>
<body itemscope itemtype="http://schema.org/CollectionPage">


<!--sphider_noindex-->

<hr />
<?php if ($commit['project']->avatar_url): ?>
<img 
    class='projavatar-small' src='<?php echo GILSUtils::getAvatarUrl($commit['project']->avatar_url); ?>' 
    alt="project <?php echo htmlspecialchars($commit['project']->name_with_namespace); ?> avatar"
    >
<?php endif; ?>
<h1 itemprop='name'><?php echo htmlspecialchars($commit['project']->name_with_namespace);?>: <?php echo htmlspecialchars($commit['commit']->short_id) ?></h1>
<hr />
<ul itemprop="breadcrumb" class="breadcrumbs">
        <li><a href="/index.html">Projects</a></li>
        <li><a href="<?php echo GILSUtils::qs2sef("proj={$commit['project']->path_with_namespace}");?>"><?php echo htmlspecialchars($commit['project']->name_with_namespace);?></a></li>
        <li><a href="<?php echo GILSUtils::qs2sef("commitproj={$commit['project']->path_with_namespace}&commit=list");?>">Commits</a></li>
        <li><a href="<?php echo GILSUtils::qs2sef("commit={$commit['commit']->id}&commitproj={$commit['project']->path_with_namespace}");?>"><?php echo htmlspecialchars($commit['commit']->short_id); ?></a></li>
</ul>
<hr />
<div class="gitlablink">
    <?php if ($template_vars['display_gitlab_links']): ?>
        <a href="<?php echo GILSUtils::forceHTTPS($commit['commit']->web_url);?>">View in Gitlab</a>
    <?php endif; ?>
    
    <?php if($commit['signature']['is_signed']): ?>
        <div class="commit_sig_status commit_sig_stat_<?php echo htmlspecialchars($commit['signature']['status']); ?>" title='Signed by "<?php echo htmlspecialchars($commit['signature']['signed_by_user']); ?>" with "<?php echo htmlspecialchars($commit['signature']['signed_by_key']); ?>"'>
           <?php echo htmlspecialchars($commit['signature']['status']); ?> 
        </div>
     <div style="clear: both"></div>
    <?php endif; ?>
</div>
<hr />

<div class='commitdetails'>
    <h3><?php echo GILSUtils::markdownToHTML($commit['commit']->title);?> </h3>
    
    <?php if ($commit['commit']->message != $commit['commit']->title): ?>
        <div class="commitmessage">
            <?php echo GILSUtils::markdownToHTML($commit['commit']->message);?>
        </div>
    <?php endif;?>
    
    <div class="commitdets">
    <p>Commit <a href="<?php echo GILSUtils::qs2sef("commit={$commit['commit']->id}&commitproj={$commit['project']->path_with_namespace}");?>"><?php echo htmlspecialchars($commit['commit']->short_id); ?></a>.</p>
    <p>Authored <?php echo $commit['commit']->authored_date; ?> by <?php echo htmlspecialchars($commit['commit']->author_name); ?> in project <a href="<?php echo GILSUtils::qs2sef("proj={$commit['project']->path_with_namespace}");?>"><?php echo htmlspecialchars($commit['project']->name_with_namespace);?></a></p>

    <?php if ($commit['commit']->committer_name != $commit['commit']->author_name): ?>
        <p><em>Committed</em> by <?php echo $commit['commit']->committed_date; ?> by <?php echo htmlspecialchars($commit['commit']->committer_name); ?> 
    <?php endif; ?>
    
    </div>
    
    <div class="commitstats">
        <span class="additions">+<?php echo $commit['commit']->stats->additions; ?> lines</span> 
        <span class="deletions">-<?php echo $commit['commit']->stats->deletions; ?> lines</span>
    </div>
    
    <?php if($commit['signature']['is_signed']): ?>
    <h3>Commit Signature</h3>
    
    <ul>
    <li>Signer: <?php echo htmlspecialchars($commit['signature']['signed_by_user']); ?></li>
    <li>Key id: <?php echo htmlspecialchars($commit['signature']['signed_by_key']); ?></li>
    <li>Status: <span class="commit_sig_str_<?php echo htmlspecialchars($commit['signature']['status']); ?>"><?php echo htmlspecialchars($commit['signature']['status']); ?></span></li>
    </ul>
    <?php endif; ?>
    
    
    <h3>Changes</h3>
    
    <div class="commitdiffwrap">
    <?php $line_no=0; ?>
    <?php foreach($commit['diff'] as $diff): ?>
        <div class="commitdiff">
            <div class="changehead">
                diff --git a/<?php echo htmlspecialchars($diff->old_path); ?> b/<?php echo htmlspecialchars($diff->new_path); ?><br />
                --- a/<?php echo htmlspecialchars($diff->old_path); ?><br />
                +++ b/<?php echo htmlspecialchars($diff->new_path); ?><br />
            </div>
            <div class="filelines">
        
            <?php 
                $lines = explode("\n", $diff->diff);
                foreach ($lines as $line):
                    $cls = (substr($line,0, 1) == "+") ? "additions" : "deletions";
                    $cls = (substr($line,0, 2) == "@@") ? "pos" : $cls;
            ?>
                    <div class="<?php echo $cls; ?>">
                            <a name="l<?php echo $line_no; ?>" href="#l<?php echo $line_no; ?>">#</a>
                            <?php echo htmlspecialchars($line);?>
                    </div>    
                <?php $line_no++; ?>
                <?php endforeach; ?>   
            </div>
        </div>
    <?php endforeach; ?>
    
    </div>
    
    <?php if (count($commit['comments']) > 0) :?>
        <h3>Comments</h3>
    <?php endif; ?>
    <div id="commentsblock">
        <?php $comment_no = 0; ?>
		<?php foreach ($commit['comments'] as $comment): ?>	
		<?php //print_r($comment); ?>
		
            <div class="activityentry activitycomment comment_author_<?php echo GILSUtils::translateUser($comment->author->username); ?>"
                itemscope itemtype="http://schema.org/Comment"
                >
                <a name="comment<?php echo $comment_no;?>"></a>
                <div class="commentMetadata">
                <b itemprop="author"><?php echo GILSUtils::translateUser($comment->author->username); ?></b>    <a itemprop="url" class="commentlink" href="#comment<?php echo $comment_no;?>" rel="nofollow">Permalink</a><br />
                <i itemprop="dateCreated"><?php echo $comment->created_at; ?></i>
                </div>
                
                <div class="commenttext" itemprop="text">

                    <?php echo GILSUtils::markdownToHTML($comment->note); ?>

                </div>
                

            </div>
            <?php $comment_no++ ;?>
		<?php endforeach; ?>
    
    
    </div>
    
    
    
</div>
<hr />
<?php if ($template_vars['display_gitlab_links']): ?>
    <div class="gitlablink">
        <a href="<?php echo GILSUtils::forceHTTPS($commit['commit']->web_url);?>">View in Gitlab</a>
    </div>
<?php endif; ?>

<hr />



<br />

<!--/sphider_noindex-->

</body>
</html>
