<?php
/** Gitlab Issue List Script
*
* Simple script to generate an simple HTML listing of Gitlab Issues from a Private Gitlab Instance
*
* @copyright (C) 2021 B Tasker (http://www.bentasker.co.uk). All rights reserved
* @license GNU GPL V3 - See LICENSE
*
* @version 1.2
*
*/

defined('listpage') or die;
?>
<html>
<head>
<meta name="viewport" content="width=device-width, initial-scale=1">
<title>Milestone <?php echo $milestone['title']; ?> : <?php echo htmlspecialchars($milestone['project']->name_with_namespace); ?></title>

<meta name="description" content="<?php echo htmlentities(utf8_encode($milestone['description'])); ?>" />

<?php require 'head-includes.php'; ?>
</head>
<body itemscope itemtype="http://schema.org/CollectionPage">


<!--sphider_noindex-->

<hr />
<?php if ($milestone['project']->avatar_url): ?>
<img 
    class='projavatar-small' src='<?php echo GILSUtils::getAvatarUrl($milestone['project']->avatar_url); ?>' 
    alt="project <?php echo htmlspecialchars($milestone['project']->name_with_namespace); ?> avatar"
    >
<?php endif; ?>
<h1 itemprop='name'><?php echo htmlspecialchars($milestone['project']->name_with_namespace);?> / Milestone: <?php echo $milestone['title']; ?></h1>
<hr />
<ul itemprop="breadcrumb" class="breadcrumbs">
        <li><a href="/index.html">Projects</a></li>
        <li><a href="<?php echo GILSUtils::qs2sef("proj={$milestone['project']->path_with_namespace}");?>"><?php echo htmlspecialchars($milestone['project']->name_with_namespace);?></a></li>
        <li>Milestones</li>
        <li><a href="<?php echo GILSUtils::qs2sef("milestone={$milestone['id']}&projpath={$milestone['project']->path_with_namespace}");?>"><?php echo $milestone['title']; ?></a></li>
</ul>
<hr />


<div class="projlinksblock">
    
</div>


<div class='projdesc'>
    <?php
        echo GILSUtils::markdownToHTML($milestone['description']);
        
        
        $issues = $milestone['issues'];
    ?>
</div>

<?php if ($template_vars['display_gitlab_links']): ?>
    <div class="gitlablink">
        <a href="<?php echo GILSUtils::forceHTTPS($milestone['web_url']);?>">View in Gitlab</a>
    </div>
<?php endif; ?>

<hr />
<h3>Issues</h3>

<?php include 'templates/html/issues-table.php'; ?>

<br />
<hr />
<br />


<!--/sphider_noindex-->

</body>
</html>


