<?php
/** Gitlab Issue List Script
*
* Simple script to generate an simple HTML listing of Gitlab Issues from a Private Gitlab Instance
*
* @copyright (C) 2021 B Tasker (http://www.bentasker.co.uk). All rights reserved
* @license GNU GPL V3 - See LICENSE
*
* @version 1.2
*
*/

defined('listpage') or die;

?>
<html>
<head>
<meta name="viewport" content="width=device-width, initial-scale=1">
<title><?php echo htmlspecialchars($project['project']->name_with_namespace); ?></title>

<meta name="description" content="<?php echo htmlentities(utf8_encode($project['project']->description)); ?>" />

<?php require 'head-includes.php'; ?>
</head>
<body itemscope itemtype="http://schema.org/CollectionPage">


<!--sphider_noindex-->

<hr />
<?php if ($project['project']->avatar_url): ?>
<img 
    class='projavatar-small' src='<?php echo GILSUtils::getAvatarUrl($project['project']->avatar_url); ?>' 
    alt="project <?php echo htmlspecialchars($project['project']->name_with_namespace); ?> avatar"
    >
<?php endif; ?>
<h1 itemprop='name'><?php echo htmlspecialchars($project['project']->name_with_namespace);?>: <?php echo htmlspecialchars($project['project']->name) ?></h1>
<hr />
<ul itemprop="breadcrumb" class="breadcrumbs">
        <li><a href="/index.html">Projects</a></li>
        <li><a href="<?php echo GILSUtils::qs2sef("proj={$project['project']->path_with_namespace}");?>"><?php echo htmlspecialchars($project['project']->name_with_namespace);?></a></li>
</ul>
<hr />


<div class="projlinksblock">

    <a href="<?php echo GILSUtils::qs2sef("commitproj={$project['project']->path_with_namespace}&commit=list");?>">Commits</a>        
        
    <?php if ($project['has_wiki']) :?>
        <a href="<?php echo GILSUtils::qs2sef("wiki={$project['project']->path_with_namespace}"); ?>">Wiki</a>
    <?php endif; ?>
    
    <?php if ($project['has_containers']) :?>
        <a href="<?php echo GILSUtils::qs2sef("container=list&contproj={$project['project']->path_with_namespace}");?>">Containers</a>
    <?php endif; ?>    
    
    
</div>


<div class='projdesc'>
    <?php
        echo GILSUtils::markdownToHTML($project['project']->description);
        
        
        $issues = $project['issues'];
    ?>
</div>

<?php if ($template_vars['display_gitlab_links']): ?>
    <div class="gitlablink">
        <a href="<?php echo GILSUtils::forceHTTPS($project['project']->web_url);?>">View in Gitlab</a>
    </div>
<?php endif; ?>

<hr />
<h3>Issues</h3>

<?php include 'templates/html/issues-table.php'; ?>

<br />

<?php if($project['releases'] && count($project['releases']) > 0): ?>
<hr />
<a name="releases"></a>
<h3>Releases</h3>

<table class="releaseslistingtable sorttable" id="projreleasestbl">
<tr>
	<th>Name</th><th>Released</th>
</tr>



<?php foreach ($project['releases'] as $rel):?>

	<tr>
        <td><a href="<?php echo GILSUtils::qs2sef("release={$rel->tag_name}&projpath={$project['project']->path_with_namespace}");?>"><?php echo $rel->name; ?></a></td>
        <td sorttable_custom_key="<?php echo strtotime($rel->released_at); ?>"><?php echo $rel->released_at; ?></td>
	</tr>

<?php endforeach; ?>
</table>

<script type="text/javascript">
      var tf = new TableFilter('projreleasestbl', {
          base_path: '/static/tablefilter/',
          auto_filter: "true",
          col_1: "select",
          col_2: "select",
          paging: true,
          paging_length: 20 
      });

      tf.init();
</script>

<?php endif; ?>



<?php if($project['milestones'] && count($project['milestones']) > 0): ?>
<hr />
<a name="milestones"></a>
<h3>Milestones</h3>

<table class="milestonelistingtable sortable" id="projmilestonestbl">
<tr>
	<th>ID</th><th>Title</th><th>Status</th>
</tr>


<?php foreach ($project['milestones'] as $mst):?>

	<tr>
        <td class="milestoneid"><a href="<?php echo GILSUtils::qs2sef("milestone={$mst->id}&projpath={$project['project']->path_with_namespace}");?>"><?php echo $mst->id; ?></a></td>
        <td class="milestonetitle"><?php echo $mst->title; ?></td>
        <td class="milestonestatus milestonestate-<?php echo $mst->state; ?>"><?php echo $mst->state; ?></td>
	</tr>

<?php endforeach; ?>
</table>


<script type="text/javascript">
      var tf = new TableFilter('projmilestonestbl', {
          base_path: '/static/tablefilter/',
          auto_filter: "true",
          col_0: "select",
          col_2: "select",
          paging: true,
          paging_length: 20 
      });

      tf.init();
</script>


<?php endif; ?>
<br />



<!--/sphider_noindex-->

</body>
</html>


